#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

# (c)2021 .direwolf <kururinmiracle@outlook.com>
# Licensed under the MIT License.

slideeasinglist = [
    'b',
    's',
    'si',
    'so',
    'sisi',
    'soso',
    'sosi',
    'siso'
]

slideeasingexlist = [
    'bb',
    'sb',
    'sib',
    'sob',
    'bs',
    'ss',
    'sis',
    'sos',
    'bsi',
    'ssi',
    'bso',
    'sso',
]

fxlist = [
    'full',
    'incremental'
]

cameraeasinglist = [
    'qi',
    'qo',
    'l',
    'reset',
    's'
]

scenetypelist = [
    'trackshow',
    'trackhide',
    'redline',
    'arcahvdistort',
    'arcahvdebris',
    'hidegroup'
]
